@@ -2,4 +2,4 @@ from explay.exp import main
 
 
 if __name__ == "__main__":
-    main()
+    ee = main()
